@@ -2,6 +2,8 @@
 
 """Main module."""
 import ssl
+
+import packaging
 import requests
 from packaging import version
 from requests_toolbelt import SSLAdapter
@@ -13,7 +15,13 @@ def get_versions(package_name):
     s.mount("https://", SSLAdapter(ssl.PROTOCOL_TLSv1_2))
     r = s.get(url)
     try:
-        versions = [version.parse(k) for k in r.json()["releases"].keys()]
+        keys = r.json()["releases"].keys()
+        versions = []
+        for k in keys:
+            try:
+                versions.append(version.parse(k))
+            except packaging.version.InvalidVersion:
+                pass
     except KeyError:
         return []
     return versions
